@@ -15,7 +15,7 @@ instance_config = {
 store_contents = get_tiddler_locations(store_contents,
     'tiddlywebplugins.console')
 store_contents['system'] = [
-    'http://svn.tiddlywiki.org/Trunk/verticals/TiddlyWebWiki/index.recipe',
+    'http://svn.tiddlywiki.org/Trunk/verticals/TiddlyWebWiki/index.recipe'
 ]
 
 store_structure = {
