@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.0.0|
+|''Version''|1.2.0|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -91,6 +91,9 @@ adaptor.prototype.getTiddlerList = function(context, userParams, callback) {
 	context = this.setContext(context, userParams, callback);
 	var uriTemplate = "%0/%1/%2/tiddlers%3";
 	var params = context.filters ? "?filter=" + context.filters : "";
+	if(context.format) {
+		params = context.format + params;
+	}
 	var workspace = adaptor.resolveWorkspace(context.workspace);
 	var uri = uriTemplate.format([context.host, workspace.type + "s",
 		adaptor.normalizeTitle(workspace.name), params]);
@@ -118,8 +121,12 @@ adaptor.getTiddlerListCallback = function(status, context, responseText, uri, xh
 		for(var i = 0; i < tiddlers.length; i++) {
 			var t = tiddlers[i];
 			var tiddler = new Tiddler(t.title);
-			tiddler.assign(t.title, null, t.modifier, t.modified, t.tags, t.created, t.fields);
-			tiddler.fields["server.workspace"] = "bags/" + t.bag;
+			t.created = Date.convertFromYYYYMMDDHHMM(t.created);
+			t.modified = Date.convertFromYYYYMMDDHHMM(t.modified);
+			tiddler.assign(t.title, t.text, t.modifier, t.modified, t.tags, t.created, t.fields);
+			tiddler.fields["server.type"] = adaptor.serverType;
+			tiddler.fields["server.host"] = AdaptorBase.minHostName(context.host);
+			tiddler.fields["server.workspace"] = context.workspace;
 			tiddler.fields["server.page.revision"] = t.revision;
 			context.tiddlers.push(tiddler);
 		}
@@ -322,7 +329,8 @@ adaptor.putTiddlerCallback = function(status, context, responseText, uri, xhr) {
 	context.statusText = xhr.statusText;
 	context.httpStatus = xhr.status;
 	if(context.status) {
-		context.adaptor.getTiddler(context.tiddler.title, context);
+		context.adaptor.getTiddler(context.tiddler.title, context,
+			context.userParams, context.callback);
 	} else if(context.callback) {
 		context.callback(context, context.userParams);
 	}
@@ -439,6 +447,7 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 	};
 	callback = callback || function() {};
 	context = this.setContext(context, userParams);
+	context.host = context.host || oldTiddler.fields["server.host"];
 	context.workspace = from.workspace || oldTiddler.fields["server.workspace"];
 	return _getTiddlerChronicle(from.title, context, userParams, _putTiddlerChronicle);
 };
